# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.split_run_summary import SplitRunSummaryParams
from ...types.next_page_token import NextPageToken


class SplitRunsListResponseParams(typing_extensions.TypedDict):
    object: typing.Literal["list"]
    data: typing.Sequence[SplitRunSummaryParams]
    next_page_token: typing_extensions.NotRequired[
        typing_extensions.Annotated[NextPageToken, FieldMetadata(alias="nextPageToken")]
    ]
