# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class EditBoundingBoxParams(typing_extensions.TypedDict):
    """
    Bounding box coordinates for the field location in the PDF (pixel coordinates)
    """

    left: float
    """
    The left coordinate of the bounding box (pixels)
    """

    top: float
    """
    The top coordinate of the bounding box (pixels)
    """

    right: float
    """
    The right coordinate of the bounding box (pixels)
    """

    bottom: float
    """
    The bottom coordinate of the bounding box (pixels)
    """
