# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class BlockMetadataPageParams(typing_extensions.TypedDict):
    """
    Information about the page this block appears on.
    """

    number: int
    """
    The page number where this block appears.
    """

    width: typing_extensions.NotRequired[float]
    """
    The width of the page in points.
    """

    height: typing_extensions.NotRequired[float]
    """
    The height of the page in points.
    """
