# This file was auto-generated by Fern from our API Definition.

import typing

from .empty_block_details import EmptyBlockDetails
from .figure_details import FigureDetails
from .table_cell_details import TableCellDetails
from .table_details import TableDetails

BlockDetails = typing.Union[TableDetails, TableCellDetails, FigureDetails, EmptyBlockDetails]
