# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.legacy_processor_run_summary import LegacyProcessorRunSummaryParams
from ...types.legacy_next_page_token import LegacyNextPageToken


class ProcessorRunListResponseParams(typing_extensions.TypedDict):
    success: bool
    processor_runs: typing_extensions.Annotated[
        typing.Sequence[LegacyProcessorRunSummaryParams], FieldMetadata(alias="processorRuns")
    ]
    next_page_token: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyNextPageToken, FieldMetadata(alias="nextPageToken")]
    ]
