# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_classify_output import ProvidedClassifyOutput
from .provided_extract_output import ProvidedExtractOutput
from .provided_split_output import ProvidedSplitOutput

ProvidedProcessorOutput = typing.Union[ProvidedExtractOutput, ProvidedClassifyOutput, ProvidedSplitOutput]
