# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ChunkMetadataPageRangeParams(typing_extensions.TypedDict):
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """

    start: int
    """
    The starting page number (inclusive).
    """

    end: int
    """
    The ending page number (inclusive).
    """
