# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CitationPageParams(typing_extensions.TypedDict):
    number: float
    """
    Page number where the citation was found. Starts at 1.
    """

    width: typing_extensions.NotRequired[float]
    """
    The width of the page in points.
    """

    height: typing_extensions.NotRequired[float]
    """
    The height of the page in points.
    """
