# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.chunk_type import ChunkType
from .block import BlockParams
from .chunk_metadata import ChunkMetadataParams


class ChunkParams(typing_extensions.TypedDict):
    object: typing.Literal["chunk"]
    """
    The type of object. In this case, it will always be `"chunk"`.
    """

    type: ChunkType
    """
    The type of chunk.
    """

    content: str
    """
    The parsed content of the chunk.
    """

    metadata: ChunkMetadataParams
    """
    Metadata about the chunk.
    """

    blocks: typing.Sequence[BlockParams]
    """
    An array of block objects that make up the chunk. A Block represents a distinct content element within a document, such as a paragraph of text, a heading, a table, or a figure. Blocks are the fundamental units that make up chunks in parsed documents.
    """
