# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_processor_type import LegacyProcessorType
from .legacy_processor_version import LegacyProcessorVersionParams


class LegacyProcessorParams(typing_extensions.TypedDict):
    object: str
    """
    The type of response. In this case, it will always be `"document_processor"`.
    """

    id: str
    """
    The ID of the processor.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    type: LegacyProcessorType
    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")]
    """
    The time (in UTC) at which the processor was created. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")]
    """
    The time (in UTC) at which the processor was last updated. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T16:45:00Z"`
    """

    draft_version: typing_extensions.Annotated[LegacyProcessorVersionParams, FieldMetadata(alias="draftVersion")]
