# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class RunUsageParams(typing_extensions.TypedDict):
    """
    Usage credits consumed by a run.

    **Availability:** This field will not be returned for:
    * Runs created before October 7, 2025
    * Customers on legacy billing systems

    For more details on how credits work, see our [Credits Guide](https://docs.extend.ai/2026-02-09/product/general/how-credits-work).
    """

    credits: float
    """
    The number of credits consumed for this run.
    """
