# This file was auto-generated by Fern from our API Definition.

"""
Provides a StrEnum base class that works across Python versions.

For Python >= 3.11, this re-exports the standard library enum.StrEnum.
For older Python versions, this defines a compatible StrEnum using the
(str, Enum) mixin pattern so that generated SDKs can use a single base
class in all supported Python versions.
"""

import enum
import sys

if sys.version_info >= (3, 11):
    from enum import StrEnum
else:

    class StrEnum(str, enum.Enum):
        pass
