# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .rule_validation_result_rules_item import RuleValidationResultRulesItem


class RuleValidationResult(UncheckedBaseModel):
    """
    The result of a rule validation step.
    """

    rules: typing.List[RuleValidationResultRulesItem] = pydantic.Field()
    """
    The list of validation rules and their results.
    """

    all_passed: typing_extensions.Annotated[bool, FieldMetadata(alias="allPassed")] = pydantic.Field(alias="allPassed")
    """
    Indicates whether all validation rules passed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
