# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.json_object import JsonObject
from .legacy_json_output_metadata_value import LegacyJsonOutputMetadataValueParams


class LegacyJsonOutputParams(typing_extensions.TypedDict):
    value: JsonObject
    """
    The extracted values conforming to the schema defined in the processor config
    """

    metadata: typing.Dict[str, LegacyJsonOutputMetadataValueParams]
    """
    Metadata about the extracted fields
    """
