# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult

LegacyProvidedFieldsArrayOutput = typing.Dict[str, LegacyProvidedExtractionFieldResult]
