# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class TableDetailsParams(typing_extensions.TypedDict):
    """
    Details for table blocks
    """

    type: typing.Literal["table_details"]
    """
    Indicates this is a table details object
    """

    row_count: typing_extensions.Annotated[int, FieldMetadata(alias="rowCount")]
    """
    The number of rows in the table
    """

    column_count: typing_extensions.Annotated[int, FieldMetadata(alias="columnCount")]
    """
    The number of columns in the table
    """
