# This file was auto-generated by Fern from our API Definition.

import typing

from .external_data_validation_result import ExternalDataValidationResultParams
from .external_data_validation_step_run_step import ExternalDataValidationStepRunStepParams
from .step_run_base import StepRunBaseParams


class ExternalDataValidationStepRunParams(StepRunBaseParams):
    step: ExternalDataValidationStepRunStepParams
    result: typing.Optional[ExternalDataValidationResultParams]
    """
    The result of this external data validation step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
