# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class FileFromIdParams(typing_extensions.TypedDict):
    """
    An Extend file ID (for instance from another run or a previous file upload).
    """

    id: str
    """
    An Extend file ID.
    
    Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`
    """
