# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class BoundingBoxParams(typing_extensions.TypedDict):
    """
    A bounding box defined by its edges.
    """

    left: typing.Optional[float]
    """
    The left coordinate of the bounding box.
    """

    top: typing.Optional[float]
    """
    The top coordinate of the bounding box.
    """

    right: typing.Optional[float]
    """
    The right coordinate of the bounding box.
    """

    bottom: typing.Optional[float]
    """
    The bottom coordinate of the bounding box.
    """
