# This file was auto-generated by Fern from our API Definition.

import typing

from ...requests.file_from_id import FileFromIdParams
from ...requests.file_from_text import FileFromTextParams
from ...requests.file_from_url import FileFromUrlParams

WorkflowRunsCreateBatchRequestInputsItemFileParams = typing.Union[
    FileFromUrlParams, FileFromIdParams, FileFromTextParams
]
