# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .provided_split_output_splits_item import ProvidedSplitOutputSplitsItemParams


class ProvidedSplitOutputParams(typing_extensions.TypedDict):
    splits: typing.Sequence[ProvidedSplitOutputSplitsItemParams]
