# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class ParseRunMetricsParams(typing_extensions.TypedDict):
    """
    Metrics about the parsing process.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    processing_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="processingTimeMs")]
    """
    The time taken to process the document in milliseconds.
    """

    page_count: typing_extensions.Annotated[float, FieldMetadata(alias="pageCount")]
    """
    The number of pages from the document that were parsed. For PDF and image files, this is the actual page count. For spreadsheet files (Excel, CSV), this is an estimated page count based on content volume (~1000 tokens per page).
    """
