# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.legacy_processor_run import LegacyProcessorRunParams


class ProcessorRunCancelResponseParams(typing_extensions.TypedDict):
    success: bool
    processor_run: typing_extensions.Annotated[LegacyProcessorRunParams, FieldMetadata(alias="processorRun")]
