# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_classifier_output import LegacyProvidedClassifierOutputParams
from .legacy_provided_extraction_output import LegacyProvidedExtractionOutputParams
from .legacy_provided_splitter_output import LegacyProvidedSplitterOutputParams

LegacyProvidedProcessorOutputParams = typing.Union[
    LegacyProvidedExtractionOutputParams, LegacyProvidedClassifierOutputParams, LegacyProvidedSplitterOutputParams
]
