# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_fields_array_output import LegacyFieldsArrayOutputParams
from .legacy_json_output import LegacyJsonOutputParams

LegacyExtractionOutputParams = typing.Union[LegacyJsonOutputParams, LegacyFieldsArrayOutputParams]
