# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ProvidedClassifyOutputParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this classification (defined in the classifier config)
    """

    type: str
    """
    The type of classification (defined in the classifier config)
    """
