# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyExtractionAdvancedOptionsReviewAgentParams(typing_extensions.TypedDict):
    """
    Configuration for the review agent that analyzes extraction results.
    When enabled, each field in the output metadata will include a `reviewAgentScore` (1-5)
    and may include additional `insights` of type `issue` or `review_summary` to help identify
    fields that may need manual review.

    To learn more, view the [Review Agent Documentation](https://docs.extend.ai/product/extraction/review-agent)
    """

    enabled: typing_extensions.NotRequired[bool]
    """
    Whether to enable the review agent for the extraction output.
    """
