# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.legacy_processor_version import LegacyProcessorVersionParams


class ProcessorVersionGetResponseParams(typing_extensions.TypedDict):
    success: bool
    version: LegacyProcessorVersionParams
    """
    A ProcessorVersion object representing the requested version of the processor.
    """
