# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class MergeExtractResultMergedExtractorsItemParams(typing_extensions.TypedDict):
    id: str
    """
    The ID of the extractor that was merged.
    """

    version_id: typing_extensions.Annotated[str, FieldMetadata(alias="versionId")]
    """
    The ID of the extractor version that was merged.
    """

    name: str
    """
    The name of the extractor that was merged.
    """
