# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_list_processors_processor import LegacyListProcessorsProcessor


class LegacyListProcessorsResponse(UncheckedBaseModel):
    success: bool = pydantic.Field()
    """
    Indicates the request was successful
    """

    warning: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional warning message
    """

    processors: typing.List[LegacyListProcessorsProcessor] = pydantic.Field()
    """
    Array of processors
    """

    next_page_token: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="nextPageToken")] = (
        pydantic.Field(alias="nextPageToken", default=None)
    )
    """
    Token for retrieving the next page of results. Will be null if there are no more results.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
