# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class FileContentsPagesItemParams(typing_extensions.TypedDict):
    page_number: typing_extensions.Annotated[int, FieldMetadata(alias="pageNumber")]
    """
    The page number of this page in the document.
    """

    page_height: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageHeight")]]
    """
    The height of the page in points. Available for PDF and IMG file types.
    """

    page_width: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageWidth")]]
    """
    The width of the page in points. Available for PDF and IMG file types.
    """

    markdown: typing_extensions.NotRequired[str]
    """
    Cleaned and structured markdown content of this page. Available for PDF and IMG file types when the `markdown` query parameter is set to true.
    """

    html: typing_extensions.NotRequired[str]
    """
    HTML content of the page. Available for DOCX file types when the `html` query parameter is set to true.
    """
