# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.file_from_id import FileFromId
from ...types.file_from_url import FileFromUrl

SplitRunsCreateRequestFile = typing.Union[FileFromUrl, FileFromId]
