# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ExcelSheetRangeParams(typing_extensions.TypedDict):
    start: int
    """
    The starting sheet index (0-based).
    """

    end: int
    """
    The ending sheet index (0-based). Must be greater than or equal to start.
    """
