# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_fields_array_output import LegacyProvidedFieldsArrayOutputParams
from .legacy_provided_json_output import LegacyProvidedJsonOutputParams

LegacyProvidedExtractionOutputParams = typing.Union[
    LegacyProvidedJsonOutputParams, LegacyProvidedFieldsArrayOutputParams
]
