# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .extract_run import ExtractRunParams
from .merge_extract_result_merged_extractors_item import MergeExtractResultMergedExtractorsItemParams


class MergeExtractResultParams(typing_extensions.TypedDict):
    """
    The result of a merge extract step, which combines outputs from multiple extraction runs into a single output.
    """

    merged_extractors: typing_extensions.Annotated[
        typing.Sequence[MergeExtractResultMergedExtractorsItemParams], FieldMetadata(alias="mergedExtractors")
    ]
    """
    The extractors that were merged to produce the output.
    """

    extract_run: typing_extensions.Annotated[ExtractRunParams, FieldMetadata(alias="extractRun")]
    """
    The resulting extract run containing the merged output.
    """
