# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class EnumOptionParams(typing_extensions.TypedDict):
    value: str
    """
    The enum value (e.g. "ANNUAL", "MONTHLY", etc.)
    """

    description: str
    """
    The description of the enum value
    """
