# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.empty_block_details import EmptyBlockDetails
from .figure_details import FigureDetailsParams
from .table_cell_details import TableCellDetailsParams
from .table_details import TableDetailsParams

BlockDetailsParams = typing.Union[TableDetailsParams, TableCellDetailsParams, FigureDetailsParams, EmptyBlockDetails]
