# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.processor_version_string import ProcessorVersionString
from .split_config import SplitConfigParams


class SplitRequestSplitterParams(typing_extensions.TypedDict):
    """
    Reference to an existing splitter. One of `splitter` or `config` must be provided.
    """

    id: str
    """
    The ID of the splitter to use.
    """

    version: typing_extensions.NotRequired[ProcessorVersionString]
    override_config: typing_extensions.NotRequired[
        typing_extensions.Annotated[SplitConfigParams, FieldMetadata(alias="overrideConfig")]
    ]
    """
    Optional configuration override. If provided, this configuration will override the splitter's saved configuration.
    """
