# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .extract_run import ExtractRunParams


class ConditionalExtractResultParams(typing_extensions.TypedDict):
    """
    The result of a conditional extract step, which routes to different extractors based on rules.
    """

    extract_run: typing_extensions.Annotated[ExtractRunParams, FieldMetadata(alias="extractRun")]
    """
    The extract run that was executed based on the matched rule.
    """
