# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.legacy_provided_extraction_field_result_type import LegacyProvidedExtractionFieldResultType


class LegacyProvidedExtractionFieldResultParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this field
    """

    value: typing.Any
    type: typing_extensions.NotRequired[LegacyProvidedExtractionFieldResultType]
    """
    The type of the extraction field result
    """

    confidence: typing_extensions.NotRequired[float]
    """
    A value between 0 and 1 indicating confidence in the extraction. Will be set to 1 if not provided.
    """

    page: typing_extensions.NotRequired[typing.Optional[float]]
    """
    The page number where this field was extracted from
    """
