# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_run_output_edited_file import EditRunOutputEditedFile


class EditRunOutput(UncheckedBaseModel):
    """
    The output of the edit run.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    edited_file: typing_extensions.Annotated[EditRunOutputEditedFile, FieldMetadata(alias="editedFile")] = (
        pydantic.Field(alias="editedFile")
    )
    """
    Information about the edited output file.
    """

    filled_values: typing_extensions.Annotated[
        typing.Optional[typing.Dict[str, typing.Any]], FieldMetadata(alias="filledValues")
    ] = pydantic.Field(alias="filledValues", default=None)
    """
    The field values that were filled into the document. Keys correspond to the property names in the schema. Will not be present if no values were filled.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
