# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class EnumParams(typing_extensions.TypedDict):
    value: str
    """
    The value of the enum option.
    """

    description: str
    """
    Description of what this enum value represents.
    """
