# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .classify_config import ClassifyConfig
from .processor_version_string import ProcessorVersionString


class ClassifyRequestClassifier(UncheckedBaseModel):
    """
    Reference to an existing classifier. One of `classifier` or `config` must be provided.
    """

    id: str = pydantic.Field()
    """
    The ID of the classifier to use.
    """

    version: typing.Optional[ProcessorVersionString] = None
    override_config: typing_extensions.Annotated[
        typing.Optional[ClassifyConfig], FieldMetadata(alias="overrideConfig")
    ] = pydantic.Field(alias="overrideConfig", default=None)
    """
    Optional configuration override. If provided, this configuration will override the classifier's saved configuration.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
