# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_extraction_field_result import LegacyExtractionFieldResult

LegacyFieldsArrayOutput = typing.Dict[str, LegacyExtractionFieldResult]
