# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .extraction_field_result_reference_bounding_boxes_item import ExtractionFieldResultReferenceBoundingBoxesItemParams


class ExtractionFieldResultReferenceParams(typing_extensions.TypedDict):
    id: str
    """
    The unique identifier for this field
    """

    field_name: typing_extensions.Annotated[str, FieldMetadata(alias="fieldName")]
    """
    The name of the extracted field
    """

    page: float
    """
    The page number that this bounding box is from
    """

    bounding_boxes: typing_extensions.Annotated[
        typing.Sequence[ExtractionFieldResultReferenceBoundingBoxesItemParams], FieldMetadata(alias="boundingBoxes")
    ]
    """
    The bounding boxes of the field
    """
