# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_classify_output import ProvidedClassifyOutputParams
from .provided_extract_output import ProvidedExtractOutputParams
from .provided_split_output import ProvidedSplitOutputParams

ProvidedProcessorOutputParams = typing.Union[
    ProvidedExtractOutputParams, ProvidedClassifyOutputParams, ProvidedSplitOutputParams
]
