# This file was auto-generated by Fern from our API Definition.

import typing

from .extraction_field_result import ExtractionFieldResult

ExtractOutputLegacy = typing.Dict[str, ExtractionFieldResult]
