# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class EditBoundingBox(UncheckedBaseModel):
    """
    Bounding box coordinates for the field location in the PDF (pixel coordinates)
    """

    left: float = pydantic.Field()
    """
    The left coordinate of the bounding box (pixels)
    """

    top: float = pydantic.Field()
    """
    The top coordinate of the bounding box (pixels)
    """

    right: float = pydantic.Field()
    """
    The right coordinate of the bounding box (pixels)
    """

    bottom: float = pydantic.Field()
    """
    The bottom coordinate of the bounding box (pixels)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
