# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class EditRunOutputEditedFileParams(typing_extensions.TypedDict):
    """
    Information about the edited output file.
    """

    id: str
    """
    The ID of the edited output file.
    """

    presigned_url: typing_extensions.Annotated[str, FieldMetadata(alias="presignedUrl")]
    """
    A presigned URL to download the edited file. Expires after 15 minutes.
    """
