# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItem


class ParseRunOutputOcr(UncheckedBaseModel):
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """

    words: typing.Optional[typing.List[ParseRunOutputOcrWordsItem]] = pydantic.Field(default=None)
    """
    An array of individual words detected by OCR.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
