# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.legacy_processor_version import LegacyProcessorVersionParams


class ProcessorVersionListResponseParams(typing_extensions.TypedDict):
    success: bool
    versions: typing.Sequence[LegacyProcessorVersionParams]
    """
    An array of ProcessorVersion objects representing all versions of the specified processor.
    """
