# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class SortDir(enum.StrEnum):
    """
    Sort in ascending or descending order. Ascending order means the earliest result is returned first.
    """

    ASC = "asc"
    DESC = "desc"
    _UNKNOWN = "__SORTDIR_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "SortDir":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        asc: typing.Callable[[], T_Result],
        desc: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is SortDir.ASC:
            return asc()
        if self is SortDir.DESC:
            return desc()
        return _unknown_member(self._value_)
