# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .chunk_metadata_page_range import ChunkMetadataPageRangeParams


class ChunkMetadataParams(typing_extensions.TypedDict):
    """
    Metadata about the chunk.
    """

    page_range: typing_extensions.Annotated[ChunkMetadataPageRangeParams, FieldMetadata(alias="pageRange")]
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """
