# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.legacy_processor import LegacyProcessorParams


class ProcessorCreateResponseParams(typing_extensions.TypedDict):
    success: bool
    processor: LegacyProcessorParams
