# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .file_summary import FileSummaryParams


class EvaluationSetItemSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["evaluation_set_item"]
    """
    The type of object. In this case, it will always be `"evaluation_set_item"`.
    """

    id: str
    """
    The ID of the evaluation set item.
    
    Example: `"evi_kR9mNP12Qw4yTv8BdR3H"`
    """

    file: FileSummaryParams
    """
    A summary of the file associated with the evaluation set item.
    """
